==> nodejs_interop-0.7.0.tar.gz: lib/src/node/cluster/cluster_module.dart <==
part of nodejs_interop.node;

/// The [`cluster`](https://nodejs.org/api/cluster.html) module.
@JS()
abstract class ClusterModule extends EventEmitter {

  /// No scheduling policy: left to the operating system.
  external static int get SCHED_NONE;

  /// The round-robin scheduling policy.
  external static int get SCHED_RR;

  /// Value indicating whether the process is a master.
  external bool get isMaster;

  /// Value indicating whether the process is a worker (i.e. not a master).
  external bool get isWorker;

  /// The scheduling policy, either [SCHED_RR] for round-robin or [SCHED_NONE] to leave it to the operating system.
  /// This is a global setting and effectively frozen once either the first worker is spawned, or [setupMaster] is called, whichever comes first.
  external int get schedulingPolicy;
  external set schedulingPolicy(int value);

  /// An object containing the cluster settings, including the default values.
  external ClusterSettings get settings;

  /// A reference to the current worker object.
  /// This property is not available in the master process.
  external Worker get worker;

  /// An object that stores the active worker objects, keyed by [Worker.id] field.
  /// This property can only be called from the master process.
  external dynamic get workers;

  /// Calls [Worker.disconnect] on each worker in [workers].
  ///
  /// This method takes an optional [callback] argument which will be called when finished.
  /// This method can only be called from the master process.
  external void disconnect([CompletionCallback0 callback]);

  /// Spawns a new worker process, optionally adding [environment] to the worker process environment.
  /// This method can only be called from the master process.
  external Worker fork([environment]);

  /// Changes the default [fork] behavior. Once called, the settings will be present in [settings].
  /// This method can only be called from the master process.
  external void setupMaster([ClusterSettings settings]);
}

/// Provides the settings of a cluster.
@JS()
@anonymous
class ClusterSettings {

  /// Creates new cluster settings.
  external factory ClusterSettings({
    List<String> args,
    String exec,
    List<String> execArgv,
    int gid,
    inspectPort,
    List stdio,
    bool silent = false,
    int uid
  });

  /// String arguments passed to worker. Defaults to `process.argv.slice(2)`.
  external List<String> get args;
  external set args(List<String> value);

  /// File path to worker file. Defaults to `process.argv[1]`.
  external String get exec;
  external set exec(String value);

  /// List of string arguments passed to the Node.js executable. Defaults to `process.execArgv`.
  external List<String> get execArgv;
  external set execArgv(List<String> value);

  /// The group identity of the process.
  external int get gid;
  external set gid(int value);

  /// The inspector port of worker. This can be an integer, or a function that takes no arguments and returns an integer.
  external dynamic get inspectPort;
  external set inspectPort(value);

  /// Value indicating whether to send output to parent's `stdio`.
  external bool get silent;
  external set silent(bool value);

  /// The `stdio` configuration of the forked processes.
  external List get stdio;
  external set stdio(List value);

  /// The user identity of the process.
  external int get uid;
  external set uid(int value);
}

==> nodejs_interop-0.8.0.tar.gz: lib/src/node/cluster/cluster_module.dart <==
part of nodejs_interop.node;

/// The [`cluster`](https://nodejs.org/api/cluster.html) module.
@JS()
abstract class ClusterModule extends EventEmitter {

  /// No scheduling policy: left to the operating system.
  external static int get SCHED_NONE; // ignore: non_constant_identifier_names

  /// The round-robin scheduling policy.
  external static int get SCHED_RR; // ignore: non_constant_identifier_names

  /// Value indicating whether the process is a master.
  external bool get isMaster;

  /// Value indicating whether the process is a worker (i.e. not a master).
  external bool get isWorker;

  /// The scheduling policy, either [SCHED_RR] for round-robin or [SCHED_NONE] to leave it to the operating system.
  /// This is a global setting and effectively frozen once either the first worker is spawned, or [setupMaster] is called, whichever comes first.
  external int get schedulingPolicy;
  external set schedulingPolicy(int value);

  /// An object containing the cluster settings, including the default values.
  external ClusterSettings get settings;

  /// A reference to the current worker object.
  /// This property is not available in the master process.
  external Worker get worker;

  /// An object that stores the active worker objects, keyed by [Worker.id] field.
  /// This property can only be called from the master process.
  external dynamic get workers;

  /// Calls [Worker.disconnect] on each worker in [workers].
  ///
  /// This method takes an optional [callback] argument which will be called when finished.
  /// This method can only be called from the master process.
  external void disconnect([CompletionCallback0 callback]);

  /// Spawns a new worker process, optionally adding [environment] to the worker process environment.
  /// This method can only be called from the master process.
  external Worker fork([environment]);

  /// Changes the default [fork] behavior. Once called, the settings will be present in [settings].
  /// This method can only be called from the master process.
  external void setupMaster([ClusterSettings settings]);
}

/// Provides the settings of a cluster.
@JS()
@anonymous
class ClusterSettings {

  /// Creates new cluster settings.
  external factory ClusterSettings({
    List<String> args,
    String exec,
    List<String> execArgv,
    int gid,
    inspectPort,
    List stdio,
    bool silent = false,
    int uid
  });

  /// String arguments passed to worker. Defaults to `process.argv.skip(2)`.
  external List<String> get args;
  external set args(List<String> value);

  /// File path to worker file. Defaults to `process.argv[1]`.
  external String get exec;
  external set exec(String value);

  /// List of string arguments passed to the Node.js executable. Defaults to `process.execArgv`.
  external List<String> get execArgv;
  external set execArgv(List<String> value);

  /// The group identity of the process.
  external int get gid;
  external set gid(int value);

  /// The inspector port of worker. This can be an integer, or a function that takes no arguments and returns an integer.
  external dynamic get inspectPort;
  external set inspectPort(value);

  /// Value indicating whether to send output to parent's `stdio`.
  external bool get silent;
  external set silent(bool value);

  /// The `stdio` configuration of the forked processes.
  external List get stdio;
  external set stdio(List value);

  /// The user identity of the process.
  external int get uid;
  external set uid(int value);
}
